aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/LiveTv/ProgramInfoDto.cs
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2013-12-02 16:46:22 -0500
committerLuke Pulverenti <luke.pulverenti@gmail.com>2013-12-02 16:46:22 -0500
commit245e92c9cc6f97e139e04548c94184c65712d3f0 (patch)
treecd957fa794a8e69871d25ea00748c1445ef58d76 /MediaBrowser.Model/LiveTv/ProgramInfoDto.cs
parentcd279d98e0574c396c0a35984e46658151e54fc0 (diff)
updated nuget
Diffstat (limited to 'MediaBrowser.Model/LiveTv/ProgramInfoDto.cs')
-rw-r--r--MediaBrowser.Model/LiveTv/ProgramInfoDto.cs24
1 files changed, 6 insertions, 18 deletions
diff --git a/MediaBrowser.Model/LiveTv/ProgramInfoDto.cs b/MediaBrowser.Model/LiveTv/ProgramInfoDto.cs
index 26cfd3cf00..6884d355d1 100644
--- a/MediaBrowser.Model/LiveTv/ProgramInfoDto.cs
+++ b/MediaBrowser.Model/LiveTv/ProgramInfoDto.cs
@@ -90,29 +90,17 @@ namespace MediaBrowser.Model.LiveTv
public DateTime? OriginalAirDate { get; set; }
/// <summary>
- /// Gets or sets the recording identifier.
+ /// Gets or sets a value indicating whether this instance is repeat.
/// </summary>
- /// <value>The recording identifier.</value>
- public string RecordingId { get; set; }
+ /// <value><c>true</c> if this instance is repeat; otherwise, <c>false</c>.</value>
+ public bool IsRepeat { get; set; }
/// <summary>
/// Gets or sets the recording status.
/// </summary>
- /// <value>The recording status.</value>
- public RecordingStatus? RecordingStatus { get; set; }
+ /// <value>The episode title.</value>
+ public string EpisodeTitle { get; set; }
- /// <summary>
- /// Gets or sets the timer identifier.
- /// </summary>
- /// <value>The timer identifier.</value>
- public string TimerId { get; set; }
-
- /// <summary>
- /// Gets or sets the timer status.
- /// </summary>
- /// <value>The timer status.</value>
- public RecordingStatus? TimerStatus { get; set; }
-
public ProgramInfoDto()
{
Genres = new List<string>();
@@ -90,29 +90,17 @@ namespace MediaBrowser.Model.LiveTv
/// <summary>
- /// Gets or sets the recording status.
+ /// Gets or sets the episode title.
/// </summary>